[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-09-21 Thread jolly
jolly has uploaded this change for review. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email )


Change subject: ASCI: Add group receive and transmit mode support to MM layer
..

ASCI: Add group receive and transmit mode support to MM layer

Related: OS#5364
Change-Id: I05957182a57423ad947ab200b52f65fde859e110
---
M src/host/layer23/include/osmocom/bb/mobile/gsm48_mm.h
M src/host/layer23/src/mobile/gsm48_mm.c
2 files changed, 700 insertions(+), 110 deletions(-)



  git pull ssh://gerrit.osmocom.org:29418/osmocom-bb refs/changes/92/34492/1

diff --git a/src/host/layer23/src/mobile/gsm48_mm.c 
b/src/host/layer23/src/mobile/gsm48_mm.c
index dc6e079..7b7cb59 100644
--- a/src/host/layer23/src/mobile/gsm48_mm.c
+++ b/src/host/layer23/src/mobile/gsm48_mm.c
@@ -144,6 +144,9 @@
  * During LIMITED SERVICE state: (4.2.2.3)
  *  - reject MM connection except for emergency calls
  *  - perform location update, if new LAI is entered
+ *  - indicate GCC/BCC calls with channel description only
+ *  - reject joining to GCC/BCC calls without channel description
+ *  - accept joining to GCC/BCC calls with channel description
  *
  *
  * The LOCATION UPDATE NEEDED state is entered if:
@@ -176,6 +179,9 @@
  *  - accept MM connection for emergency calls
  *  - trigger location update on any other MM connection
 

[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-09-21 Thread Jenkins Builder
Jenkins Builder has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email )

Change subject: ASCI: Add group receive and transmit mode support to MM layer
..


Patch Set 1:

(4 comments)

File src/host/layer23/src/mobile/gsm48_mm.c:

Robot Comment from checkpatch (run ID jenkins-gerrit-lint-11171):
https://gerrit.osmocom.org/c/osmocom-bb/+/34492/comment/c83585cb_7a20f258
PS1, Line 277:  *   completely independant from the state of the MM layer.
'independant' may be misspelled - perhaps 'independent'?


Robot Comment from checkpatch (run ID jenkins-gerrit-lint-11171):
https://gerrit.osmocom.org/c/osmocom-bb/+/34492/comment/ccc37e3f_ad5f5bb6
PS1, Line 3822: msg_type = (mm->vgcs_group_call) ? 
GSM48_MMGCC_GROUP_CNF: GSM48_MMBCC_GROUP_CNF;
spaces required around that ':' (ctx:VxW)


Robot Comment from checkpatch (run ID jenkins-gerrit-lint-11171):
https://gerrit.osmocom.org/c/osmocom-bb/+/34492/comment/99c5b470_08d4b251
PS1, Line 3967: msg_type = (mm->vgcs_group_call) ? 
GSM48_MMGCC_UPLINK_CNF: GSM48_MMBCC_UPLINK_CNF;
spaces required around that ':' (ctx:VxW)


Robot Comment from checkpatch (run ID jenkins-gerrit-lint-11171):
https://gerrit.osmocom.org/c/osmocom-bb/+/34492/comment/422042c4_38c79d66
PS1, Line 3993: msg_type = (mm->vgcs_group_call) ? 
GSM48_MMGCC_UPLINK_REL_IND: GSM48_MMBCC_UPLINK_REL_IND;
spaces required around that ':' (ctx:VxW)



diff --git a/src/host/layer23/src/mobile/gsm48_mm.c 
b/src/host/layer23/src/mobile/gsm48_mm.c
index 8c57785..82e5fad 100644
--- a/src/host/layer23/src/mobile/gsm48_mm.c
+++ b/src/host/layer23/src/mobile/gsm48_mm.c
@@ -60,6 +60,7 @@
 static int gsm48_mm_loc_upd_normal(struct osmocom_ms *ms, struct msgb *msg);
 static
diff --git a/src/host/layer23/include/osmocom/bb/mobile/gsm48_mm.h 
b/src/host/layer23/include/osmocom/bb/mobile/gsm48_mm.h
index 4f47c9b..d0de235 100644
--- a/src/host/layer23/include/osmocom/bb/mobile/gsm48_mm.h
+++ b/src/host/layer23/include/osmocom/bb/mobile/gsm48_mm.h
@@ -8,8 +8,8 @@
 #define GSM48_MMCC_CLASS   0x100
 #define GSM48_MMSS_CLASS   0x200
 #define GSM48_MMSMS_CLASS  0x300
-#define GSM48_MMBCC_CLASS  0x500
-#define GSM48_MMGCC_CLASS  0x600
+#define GSM48_MMGCC_CLASS  0x500
+#define GSM48_MMBCC_CLASS  0x600
 #define GSM48_MMXX_REL_IND 0x022
 #define GSM48_MMCC_EST_REQ 0x110
 #define GSM48_MMCC_EST_IND 0x112
@@ -66,6 +66,13 @@
 #define GSM48_MMGCC_REEST_REQ  0x560
 #define GSM48_MMGCC_REEST_CNF  0x561
 #define GSM48_MMGCC_ERR_IND0x572
+#define GSM48_MMGCC_NOTIF_IND  0x582
+#define GSM48_MMGCC_GROUP_REQ  0x590
+#define GSM48_MMGCC_GROUP_CNF  0x591
+#define GSM48_MMGCC_UPLINK_REQ 0x5a0
+#define GSM48_MMGCC_UPLINK_CNF 0x5a1
+#define GSM48_MMGCC_UPLINK_REL_REQ 0x5a8
+#define GSM48_MMGCC_UPLINK_REL_IND 0x5aa
 #define GSM48_MMBCC_EST_REQ0x610
 #define GSM48_MMBCC_EST_CNF0x611
 #define GSM48_MMBCC_REL_REQ0x620
@@ -77,18 +84,32 @@
 #define GSM48_MMBCC_REEST_REQ  0x660
 #define GSM48_MMBCC_REEST_CNF  0x661
 #define GSM48_MMBCC_ERR_IND0x672
+#define GSM48_MMBCC_NOTIF_IND  0x682
+#define GSM48_MMBCC_GROUP_REQ  0x690
+#define GSM48_MMBCC_GROUP_CNF  0x691
+#define GSM48_MMBCC_UPLINK_REQ 0x6a0
+#define GSM48_MMBCC_UPLINK_CNF 0x6a1
+#define GSM48_MMBCC_UPLINK_REL_REQ 0x6a8
+#define GSM48_MMBCC_UPLINK_REL_IND 0x6aa
+

 #define MMXX_ALLOC_SIZE256
 #define MMXX_ALLOC_HEADROOM64

+#define MMXX_NOTIFY_SETUP  0
+#define MMXX_NOTIFY_RELEASE1
+
 /* MMxx-SAP header */
 struct gsm48_mmxx_hdr {
-   uint16_tmsg_type; /* MMxx_* primitive */
-   uint32_tref; /* reference to transaction */
-   uint32_ttransaction_id; /* transaction identifier */
-   uint8_t sapi; /* sapi */
-   uint8_t emergency; /* emergency type of call */
-   uint8_t cause; /* cause used for release */
+   uint16_tmsg_type; /* MMxx_* primitive */
+   uint32_tref; /* reference to transaction */
+   uint32_ttransaction_id; /* transaction identifier */
+   uint8_t sapi; /* sapi */
+   uint8_t emergency; /* emergency type of call */
+   uint8_t cause; /* cause used for release */
+   uint8_t notify; /* notify ongoing ASCI call */
+   boolch_desc_present; /* notifies channel */
+   struct gsm48_chan_desc  ch_desc; /* group channel */
 } __attribute__((packed));

 /* GSM 6.1.2 */
@@ -233,6 +254,12 @@

/* sapi 3 */
int sapi3_link;
+
+   /* VGCS additional states */
+   boolvgcs;   /* We are in 
group/broadcast mode. */
+   boolvgcs_group_call;/* This is a group 
call. */
+   uint32_tvgcs_callref;   /* Callref of this 
call. */
+   boolvgcs_normal_service;/* Service state before 
group transmit mode. */
 };

 /* MM connection entry */
--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 1
Gerrit-Owner: jolly 
Gerrit-CC: Jenkins Builder
Gerrit-Comment-Date: Thu, 21 Sep 2023 09:39:46 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Gerrit-MessageType: comment


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-09-21 Thread jolly
Attention is currently required from: jolly.

Hello Jenkins Builder,

I'd like you to reexamine a change. Please visit

https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email

to look at the new patch set (#2).

The following approvals got outdated and were removed:
Verified-1 by Jenkins Builder


Change subject: ASCI: Add group receive and transmit mode support to MM layer
..

ASCI: Add group receive and transmit mode support to MM layer

Related: OS#5364
Change-Id: I05957182a57423ad947ab200b52f65fde859e110
---
M src/host/layer23/include/osmocom/bb/mobile/gsm48_mm.h
M src/host/layer23/src/mobile/gsm48_mm.c
2 files changed, 700 insertions(+), 110 deletions(-)


  git pull ssh://gerrit.osmocom.org:29418/osmocom-bb refs/changes/92/34492/2
--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 2
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Attention: jolly 
Gerrit-MessageType: newpatchset


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-09-21 Thread jolly
Attention is currently required from: jolly.

Hello Jenkins Builder,

I'd like you to reexamine a change. Please visit

https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email

to look at the new patch set (#3).

The following approvals got outdated and were removed:
Verified-1 by Jenkins Builder


Change subject: ASCI: Add group receive and transmit mode support to MM layer
..

ASCI: Add group receive and transmit mode support to MM layer

Related: OS#5364
Change-Id: I05957182a57423ad947ab200b52f65fde859e110
---
M src/host/layer23/include/osmocom/bb/mobile/gsm48_mm.h
M src/host/layer23/src/mobile/gsm48_mm.c
2 files changed, 704 insertions(+), 110 deletions(-)


  git pull ssh://gerrit.osmocom.org:29418/osmocom-bb refs/changes/92/34492/3
--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 3
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Attention: jolly 
Gerrit-MessageType: newpatchset


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-09-21 Thread pespin
Attention is currently required from: jolly.

pespin has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email )

Change subject: ASCI: Add group receive and transmit mode support to MM layer
..


Patch Set 5: Code-Review+1

(1 comment)

File src/host/layer23/include/osmocom/bb/mobile/gsm48_mm.h:

https://gerrit.osmocom.org/c/osmocom-bb/+/34492/comment/c8d068b1_989bd67a
PS5, Line 262:  /* VGCS additional states */
struct vcgs?



--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 5
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: pespin 
Gerrit-Attention: jolly 
Gerrit-Comment-Date: Thu, 21 Sep 2023 14:25:39 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-09-26 Thread jolly
Attention is currently required from: jolly, pespin.

Hello Jenkins Builder, pespin,

I'd like you to reexamine a change. Please visit

https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email

to look at the new patch set (#6).

The following approvals got outdated and were removed:
Code-Review+1 by pespin, Verified+1 by Jenkins Builder


Change subject: ASCI: Add group receive and transmit mode support to MM layer
..

ASCI: Add group receive and transmit mode support to MM layer

Related: OS#5364
Change-Id: I05957182a57423ad947ab200b52f65fde859e110
---
M src/host/layer23/include/osmocom/bb/mobile/gsm48_mm.h
M src/host/layer23/src/mobile/gsm48_mm.c
2 files changed, 707 insertions(+), 106 deletions(-)


  git pull ssh://gerrit.osmocom.org:29418/osmocom-bb refs/changes/92/34492/6
--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 6
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: pespin 
Gerrit-Attention: jolly 
Gerrit-Attention: pespin 
Gerrit-MessageType: newpatchset


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-09-26 Thread jolly
Attention is currently required from: pespin.

jolly has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email )

Change subject: ASCI: Add group receive and transmit mode support to MM layer
..


Patch Set 6:

(1 comment)

File src/host/layer23/include/osmocom/bb/mobile/gsm48_mm.h:

https://gerrit.osmocom.org/c/osmocom-bb/+/34492/comment/97a1474d_1f2bb5eb
PS5, Line 262:  /* VGCS additional states */
> struct vcgs?
Done



--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 6
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: pespin 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Tue, 26 Sep 2023 10:26:42 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: pespin 
Gerrit-MessageType: comment


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-09-26 Thread pespin
Attention is currently required from: jolly.

pespin has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email )

Change subject: ASCI: Add group receive and transmit mode support to MM layer
..


Patch Set 8: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 8
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: pespin 
Gerrit-Attention: jolly 
Gerrit-Comment-Date: Tue, 26 Sep 2023 12:31:10 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-09-26 Thread laforge
Attention is currently required from: jolly.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email )

Change subject: ASCI: Add group receive and transmit mode support to MM layer
..


Patch Set 8: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 8
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-Attention: jolly 
Gerrit-Comment-Date: Tue, 26 Sep 2023 13:58:55 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-09-26 Thread fixeria
Attention is currently required from: jolly.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email )

Change subject: ASCI: Add group receive and transmit mode support to MM layer
..


Patch Set 8:

(3 comments)

File src/host/layer23/src/mobile/gsm48_mm.c:

https://gerrit.osmocom.org/c/osmocom-bb/+/34492/comment/10ea07b5_7619540d
PS8, Line 4643: if (rr_prim != -1) {
Doing `goto` from the `default` branch above might be a more elegant solution.
(Gerrit highlighting is rather confusing, it looks as if the whole block was 
changed, but actually it was only shifted right).


https://gerrit.osmocom.org/c/osmocom-bb/+/34492/comment/53ededef_24de43e8
PS8, Line 4813: nothing here
TODO/FIXME?


https://gerrit.osmocom.org/c/osmocom-bb/+/34492/comment/82842821_cdcae8a9
PS8, Line 4851: nothing here
TODO/FIXME?



--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 8
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-CC: fixeria 
Gerrit-Attention: jolly 
Gerrit-Comment-Date: Tue, 26 Sep 2023 15:39:01 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Gerrit-MessageType: comment


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-09-27 Thread jolly
Attention is currently required from: jolly, laforge, pespin.

Hello Jenkins Builder, laforge, pespin,

I'd like you to reexamine a change. Please visit

https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email

to look at the new patch set (#9).

The following approvals got outdated and were removed:
Code-Review+1 by laforge, Code-Review+1 by pespin, Verified+1 by Jenkins Builder


Change subject: ASCI: Add group receive and transmit mode support to MM layer
..

ASCI: Add group receive and transmit mode support to MM layer

Related: OS#5364
Change-Id: I05957182a57423ad947ab200b52f65fde859e110
---
M src/host/layer23/include/osmocom/bb/mobile/gsm48_mm.h
M src/host/layer23/src/mobile/gsm48_mm.c
2 files changed, 687 insertions(+), 83 deletions(-)


  git pull ssh://gerrit.osmocom.org:29418/osmocom-bb refs/changes/92/34492/9
--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 9
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-CC: fixeria 
Gerrit-Attention: jolly 
Gerrit-Attention: laforge 
Gerrit-Attention: pespin 
Gerrit-MessageType: newpatchset


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-09-27 Thread jolly
Attention is currently required from: fixeria, laforge, pespin.

jolly has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email )

Change subject: ASCI: Add group receive and transmit mode support to MM layer
..


Patch Set 9:

(3 comments)

File src/host/layer23/src/mobile/gsm48_mm.c:

https://gerrit.osmocom.org/c/osmocom-bb/+/34492/comment/c0899843_b71e1d95
PS8, Line 4643: if (rr_prim != -1) {
> Doing `goto` from the `default` branch above might be a more elegant 
> solution. […]
Good idea. Lets see how it looks like.


https://gerrit.osmocom.org/c/osmocom-bb/+/34492/comment/e938ee0c_3cf5f674
PS8, Line 4813: nothing here
> TODO/FIXME?
I improved the description, to make clear why there is no handler here.


https://gerrit.osmocom.org/c/osmocom-bb/+/34492/comment/2b2cbca6_7ab2cf16
PS8, Line 4851: nothing here
> TODO/FIXME?
dito



--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 9
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-CC: fixeria 
Gerrit-Attention: laforge 
Gerrit-Attention: fixeria 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Wed, 27 Sep 2023 12:50:23 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: fixeria 
Gerrit-MessageType: comment


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-09-27 Thread pespin
Attention is currently required from: fixeria, jolly, laforge.

pespin has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email )

Change subject: ASCI: Add group receive and transmit mode support to MM layer
..


Patch Set 10:

(1 comment)

File src/host/layer23/src/mobile/gsm48_mm.c:

https://gerrit.osmocom.org/c/osmocom-bb/+/34492/comment/8e4242e9_ea64b6a4
PS10, Line 4854:// There are event handlers for group call in this 
implementation.
not sure what do you mean with this.



--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 10
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-CC: fixeria 
Gerrit-Attention: jolly 
Gerrit-Attention: laforge 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Wed, 27 Sep 2023 13:57:38 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Gerrit-MessageType: comment


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-09-28 Thread jolly
Attention is currently required from: fixeria, laforge, pespin.

jolly has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email )

Change subject: ASCI: Add group receive and transmit mode support to MM layer
..


Patch Set 12:

(1 comment)

File src/host/layer23/src/mobile/gsm48_mm.c:

https://gerrit.osmocom.org/c/osmocom-bb/+/34492/comment/058305d5_3478639a
PS10, Line 4854:// There are event handlers for group call in this 
implementation.
> not sure what do you mean with this.
Oops, I missed some words. I rephrased it.



--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 12
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-CC: fixeria 
Gerrit-Attention: laforge 
Gerrit-Attention: pespin 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Thu, 28 Sep 2023 11:52:43 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: pespin 
Gerrit-MessageType: comment


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-09-28 Thread jolly
Attention is currently required from: fixeria, laforge, pespin.

Hello Jenkins Builder, laforge, pespin,

I'd like you to reexamine a change. Please visit

https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email

to look at the new patch set (#13).

The following approvals got outdated and were removed:
Verified+1 by Jenkins Builder


Change subject: ASCI: Add group receive and transmit mode support to MM layer
..

ASCI: Add group receive and transmit mode support to MM layer

Related: OS#5364
Change-Id: I05957182a57423ad947ab200b52f65fde859e110
---
M src/host/layer23/include/osmocom/bb/mobile/gsm48_mm.h
M src/host/layer23/src/mobile/gsm48_mm.c
2 files changed, 677 insertions(+), 77 deletions(-)


  git pull ssh://gerrit.osmocom.org:29418/osmocom-bb refs/changes/92/34492/13
--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 13
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-CC: fixeria 
Gerrit-Attention: laforge 
Gerrit-Attention: pespin 
Gerrit-Attention: fixeria 
Gerrit-MessageType: newpatchset


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-09-28 Thread pespin
Attention is currently required from: fixeria, jolly, laforge.

pespin has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email )

Change subject: ASCI: Add group receive and transmit mode support to MM layer
..


Patch Set 13:

(1 comment)

File src/host/layer23/src/mobile/gsm48_mm.c:

https://gerrit.osmocom.org/c/osmocom-bb/+/34492/comment/9783c735_a3e48771
PS10, Line 4854:// There are event handlers for group call in this 
implementation.
> Oops, I missed some words. I rephrased it.
v13 still hasn't this rephreased afaict.



--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 13
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-CC: fixeria 
Gerrit-Attention: jolly 
Gerrit-Attention: laforge 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Thu, 28 Sep 2023 12:01:40 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: jolly 
Comment-In-Reply-To: pespin 
Gerrit-MessageType: comment


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-09-30 Thread fixeria
Attention is currently required from: jolly, laforge.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email )

Change subject: ASCI: Add group receive and transmit mode support to MM layer
..


Patch Set 13:

(1 comment)

File src/host/layer23/src/mobile/gsm48_mm.c:

https://gerrit.osmocom.org/c/osmocom-bb/+/34492/comment/908d9e92_e20214e9
PS8, Line 4643: if (rr_prim != -1) {
> Good idea. Lets see how it looks like.
Done



--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 13
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-CC: fixeria 
Gerrit-Attention: jolly 
Gerrit-Attention: laforge 
Gerrit-Comment-Date: Sat, 30 Sep 2023 09:01:48 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: jolly 
Comment-In-Reply-To: fixeria 
Gerrit-MessageType: comment


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-09-30 Thread fixeria
Attention is currently required from: jolly, laforge, pespin.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email )

Change subject: ASCI: Add group receive and transmit mode support to MM layer
..


Patch Set 13:

(1 comment)

File src/host/layer23/src/mobile/gsm48_mm.c:

https://gerrit.osmocom.org/c/osmocom-bb/+/34492/comment/f45e4363_881815b3
PS10, Line 4854:// There are event handlers for group call in this 
implementation.
> v13 still hasn't this rephreased afaict.
Fixed in https://gerrit.osmocom.org/c/osmocom-bb/+/34556, which should be 
squashed here.



--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 13
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-CC: fixeria 
Gerrit-Attention: jolly 
Gerrit-Attention: laforge 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Sat, 30 Sep 2023 09:17:19 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: jolly 
Comment-In-Reply-To: pespin 
Gerrit-MessageType: comment


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-10-02 Thread jolly
Attention is currently required from: jolly, laforge, pespin.

Hello Jenkins Builder, laforge, pespin,

I'd like you to reexamine a change. Please visit

https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email

to look at the new patch set (#14).

The following approvals got outdated and were removed:
Verified+1 by Jenkins Builder


Change subject: ASCI: Add group receive and transmit mode support to MM layer
..

ASCI: Add group receive and transmit mode support to MM layer

Related: OS#5364
Change-Id: I05957182a57423ad947ab200b52f65fde859e110
---
M src/host/layer23/include/osmocom/bb/mobile/gsm48_mm.h
M src/host/layer23/src/mobile/gsm48_mm.c
2 files changed, 710 insertions(+), 78 deletions(-)


  git pull ssh://gerrit.osmocom.org:29418/osmocom-bb refs/changes/92/34492/14
--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 14
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-CC: fixeria 
Gerrit-Attention: jolly 
Gerrit-Attention: laforge 
Gerrit-Attention: pespin 
Gerrit-MessageType: newpatchset


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-10-02 Thread jolly
Attention is currently required from: fixeria, laforge, pespin.

jolly has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email )

Change subject: ASCI: Add group receive and transmit mode support to MM layer
..


Patch Set 14:

(1 comment)

File src/host/layer23/src/mobile/gsm48_mm.c:

https://gerrit.osmocom.org/c/osmocom-bb/+/34492/comment/ed70ef49_e4e79682
PS10, Line 4854:// There are event handlers for group call in this 
implementation.
> Fixed in https://gerrit.osmocom.org/c/osmocom-bb/+/34556, which should be 
> squashed here.
Yes, it is squashed now.



--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 14
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-CC: fixeria 
Gerrit-Attention: laforge 
Gerrit-Attention: fixeria 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Mon, 02 Oct 2023 11:44:33 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: jolly 
Comment-In-Reply-To: fixeria 
Comment-In-Reply-To: pespin 
Gerrit-MessageType: comment


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-10-02 Thread pespin
Attention is currently required from: fixeria, jolly, laforge.

pespin has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email )

Change subject: ASCI: Add group receive and transmit mode support to MM layer
..


Patch Set 14: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 14
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-CC: fixeria 
Gerrit-Attention: jolly 
Gerrit-Attention: laforge 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Mon, 02 Oct 2023 14:21:33 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-10-02 Thread fixeria
Attention is currently required from: jolly, laforge.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email )

Change subject: ASCI: Add group receive and transmit mode support to MM layer
..


Patch Set 14: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 14
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-Attention: jolly 
Gerrit-Attention: laforge 
Gerrit-Comment-Date: Tue, 03 Oct 2023 05:38:57 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-10-03 Thread jolly
Attention is currently required from: jolly, laforge.

Hello Jenkins Builder, fixeria, laforge, pespin,

I'd like you to reexamine a change. Please visit

https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email

to look at the new patch set (#15).

The following approvals got outdated and were removed:
Verified+1 by Jenkins Builder

The change is no longer submittable: Verified is unsatisfied now.


Change subject: ASCI: Add group receive and transmit mode support to MM layer
..

ASCI: Add group receive and transmit mode support to MM layer

Related: OS#5364
Change-Id: I05957182a57423ad947ab200b52f65fde859e110
---
M src/host/layer23/include/osmocom/bb/mobile/gsm48_mm.h
M src/host/layer23/src/mobile/gsm48_mm.c
2 files changed, 710 insertions(+), 78 deletions(-)


  git pull ssh://gerrit.osmocom.org:29418/osmocom-bb refs/changes/92/34492/15
--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I05957182a57423ad947ab200b52f65fde859e110
Gerrit-Change-Number: 34492
Gerrit-PatchSet: 15
Gerrit-Owner: jolly 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-Attention: jolly 
Gerrit-Attention: laforge 
Gerrit-MessageType: newpatchset


[L] Change in osmocom-bb[master]: ASCI: Add group receive and transmit mode support to MM layer

2023-10-03 Thread laforge
laforge has submitted this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/34492?usp=email )

 (

14 is the latest approved patch-set.
No files were changed between the latest approved patch-set and the submitted 
one.
 )Change subject: ASCI: Add group receive and transmit mode support to MM layer
..

ASCI: Add group receive and transmit mode support to MM layer

Related: OS#5364
Change-Id: I05957182a57423ad947ab200b52f65fde859e110
---
M src/host/layer23/include/osmocom/bb/mobile/gsm48_mm.h
M src/host/layer23/src/mobile/gsm48_mm.c
2 files changed, 710 insertions(+), 78 deletions(-)

Approvals:
  pespin: Looks good to me, but someone else must approve
  Jenkins Builder: Verified
  fixeria: Looks good to me, approved




diff --git a/src/host/layer23/include/osmocom/bb/mobile/gsm48_mm.h 
b/src/host/layer23/include/osmocom/bb/mobile/gsm48_mm.h
index 67abc2f..1f0db78 100644
--- a/src/host/layer23/include/osmocom/bb/mobile/gsm48_mm.h
+++ b/src/host/layer23/include/osmocom/bb/mobile/gsm48_mm.h
@@ -8,8 +8,8 @@
 #define GSM48_MMCC_CLASS   0x100
 #define GSM48_MMSS_CLASS   0x200
 #define GSM48_MMSMS_CLASS  0x300
-#define GSM48_MMBCC_CLASS  0x500
-#define GSM48_MMGCC_CLASS  0x600
+#define GSM48_MMGCC_CLASS  0x500
+#define GSM48_MMBCC_CLASS  0x600
 #define GSM48_MMXX_REL_IND 0x022
 #define GSM48_MMCC_EST_REQ 0x110
 #define GSM48_MMCC_EST_IND 0x112
@@ -66,6 +66,15 @@
 #define GSM48_MMGCC_REEST_REQ  0x560
 #define GSM48_MMGCC_REEST_CNF  0x561
 #define GSM48_MMGCC_ERR_IND0x572
+#define GSM48_MMGCC_NOTIF_IND  0x582
+#define GSM48_MMGCC_GROUP_REQ  0x590
+#define GSM48_MMGCC_GROUP_CNF  0x591
+#define GSM48_MMGCC_UPLINK_REQ 0x5a0
+#define GSM48_MMGCC_UPLINK_CNF 0x5a1
+#define GSM48_MMGCC_UPLINK_REL_REQ 0x5a8
+#define GSM48_MMGCC_UPLINK_REL_IND 0x5aa
+#define GSM48_MMGCC_UPLINK_FREE_IND0x5b2
+#define GSM48_MMGCC_UPLINK_BUSY_IND0x5b6
 #define GSM48_MMBCC_EST_REQ0x610
 #define GSM48_MMBCC_EST_CNF0x611
 #define GSM48_MMBCC_REL_REQ0x620
@@ -77,18 +86,34 @@
 #define GSM48_MMBCC_REEST_REQ  0x660
 #define GSM48_MMBCC_REEST_CNF  0x661
 #define GSM48_MMBCC_ERR_IND0x672
+#define GSM48_MMBCC_NOTIF_IND  0x682
+#define GSM48_MMBCC_GROUP_REQ  0x690
+#define GSM48_MMBCC_GROUP_CNF  0x691
+#define GSM48_MMBCC_UPLINK_REQ 0x6a0
+#define GSM48_MMBCC_UPLINK_CNF 0x6a1
+#define GSM48_MMBCC_UPLINK_REL_REQ 0x6a8
+#define GSM48_MMBCC_UPLINK_REL_IND 0x6aa
+#define GSM48_MMBCC_UPLINK_FREE_IND0x6b2
+#define GSM48_MMBCC_UPLINK_BUSY_IND0x6b6
+

 #define MMXX_ALLOC_SIZE256
 #define MMXX_ALLOC_HEADROOM64

+#define MMXX_NOTIFY_SETUP  0
+#define MMXX_NOTIFY_RELEASE1
+
 /* MMxx-SAP header */
 struct gsm48_mmxx_hdr {
-   uint16_tmsg_type; /* MMxx_* primitive */
-   uint32_tref; /* reference to transaction */
-   uint32_ttransaction_id; /* transaction identifier */
-   uint8_t sapi; /* sapi */
-   uint8_t emergency; /* emergency type of call */
-   uint8_t cause; /* cause used for release */
+   uint16_tmsg_type; /* MMxx_* primitive */
+   uint32_tref; /* reference to transaction */
+   uint32_ttransaction_id; /* transaction identifier */
+   uint8_t sapi; /* sapi */
+   uint8_t emergency; /* emergency type of call */
+   uint8_t cause; /* cause used for release */
+   uint8_t notify; /* notify ongoing ASCI call */
+   boolch_desc_present; /* notifies channel */
+   struct gsm48_chan_desc  ch_desc; /* group channel */
 } __attribute__((packed));

 /* GSM 6.1.2 */
@@ -237,6 +262,14 @@

/* sapi 3 */
int sapi3_link;
+
+   /* VGCS additional states */
+   struct {
+   boolenabled;/* We are in 
group/broadcast mode. */
+   boolgroup_call; /* This is a 
group call, not a broadcast call. */
+   uint32_tcallref;/* Callref of 
this call. */
+   boolnormal_service; /* Service 
state before group transmit mode. */
+   } vgcs;
 };

 /* MM connection entry */